@@ -1,7 +1,8 @@
 import os
 import re
 
-from collections import Sequence, defaultdict
+from collections import defaultdict
+from collections.abc import Sequence
 
 catagolue_url = "https://catagolue.hatsya.com"
 
